Struct rkyv::niche::option_nonzero::ArchivedOptionNonZeroI8 [−][src]
#[repr(transparent)]pub struct ArchivedOptionNonZeroI8 { /* fields omitted */ }Expand description
A niched archived Option<NonZeroI8>
Implementations
Converts to an Option<&Archived<NonZeroI8>>
Converts to an Option<&mut Archived<NonZeroI8>>
Converts from Pin<&ArchivedOptionNonZeroI8> to Option<Pin<&Archived<NonZeroI8>>>.
Converts from Pin<&mut ArchivedOptionNonZeroI8> to Option<Pin<&mut Archived<NonZeroI8>>>.
Returns an iterator over the possibly contained value.
Returns a mutable iterator over the possibly contained value.
Inserts v into the option if it is None, then returns a mutable
reference to the contained value.
Inserts a value computed from f into the option if it is None, then
returns a mutable reference to the contained value.