Struct rkyv::niche::option_nonzero::ArchivedOptionNonZeroU128 [−][src]
#[repr(transparent)]pub struct ArchivedOptionNonZeroU128 { /* fields omitted */ }Expand description
A niched archived Option<NonZeroU128>
Implementations
Converts to an Option<&Archived<NonZeroU128>>
Converts to an Option<&mut Archived<NonZeroU128>>
Converts from Pin<&ArchivedOptionNonZeroU128> to Option<Pin<&Archived<NonZeroU128>>>.
Converts from Pin<&mut ArchivedOptionNonZeroU128> to Option<Pin<&mut Archived<NonZeroU128>>>.
Returns an iterator over the possibly contained value.
Returns a mutable iterator over the possibly contained value.
Inserts v into the option if it is None, then returns a mutable
reference to the contained value.
pub fn get_or_insert_with<F: FnOnce() -> NonZeroU128>(
&mut self,
f: F
) -> &mut Archived<NonZeroU128>
pub fn get_or_insert_with<F: FnOnce() -> NonZeroU128>(
&mut self,
f: F
) -> &mut Archived<NonZeroU128>
Inserts a value computed from f into the option if it is None, then
returns a mutable reference to the contained value.
Resolves an ArchivedOptionNonZero from an Option<NonZero>.
Safety
posmust be the position ofoutwithin the archive