Struct rkyv::niche::option_nonzero::ArchivedOptionNonZeroU16 [−][src]
#[repr(transparent)]pub struct ArchivedOptionNonZeroU16 { /* fields omitted */ }Expand description
A niched archived Option<NonZeroU16>
Implementations
Converts to an Option<&Archived<NonZeroU16>>
Converts to an Option<&mut Archived<NonZeroU16>>
Converts from Pin<&ArchivedOptionNonZeroU16> to Option<Pin<&Archived<NonZeroU16>>>.
Converts from Pin<&mut ArchivedOptionNonZeroU16> to Option<Pin<&mut Archived<NonZeroU16>>>.
Returns an iterator over the possibly contained value.
Returns a mutable iterator over the possibly contained value.
Inserts v into the option if it is None, then returns a mutable
reference to the contained value.
pub fn get_or_insert_with<F: FnOnce() -> NonZeroU16>(
&mut self,
f: F
) -> &mut Archived<NonZeroU16>
pub fn get_or_insert_with<F: FnOnce() -> NonZeroU16>(
&mut self,
f: F
) -> &mut Archived<NonZeroU16>
Inserts a value computed from f into the option if it is None, then
returns a mutable reference to the contained value.
Resolves an ArchivedOptionNonZero from an Option<NonZero>.
Safety
posmust be the position ofoutwithin the archive