Struct rkyv::niche::option_nonzero::ArchivedOptionNonZeroU8 [−][src]
#[repr(transparent)]pub struct ArchivedOptionNonZeroU8 { /* fields omitted */ }Expand description
A niched archived Option<NonZeroU8>
Implementations
Converts to an Option<&Archived<NonZeroU8>>
Converts to an Option<&mut Archived<NonZeroU8>>
Converts from Pin<&ArchivedOptionNonZeroU8> to Option<Pin<&Archived<NonZeroU8>>>.
Converts from Pin<&mut ArchivedOptionNonZeroU8> to Option<Pin<&mut Archived<NonZeroU8>>>.
Returns an iterator over the possibly contained value.
Returns a mutable iterator over the possibly contained value.
Inserts v into the option if it is None, then returns a mutable
reference to the contained value.
Inserts a value computed from f into the option if it is None, then
returns a mutable reference to the contained value.